@@ -1,9 +1,9 @@
 """Color definitions are used as per the CSS3
 [CSS Color Module Level 3](http://www.w3.org/TR/css3-color/#svg-color) specification.
 
-A few colors have multiple names referring to the sames colors, eg. `grey` and `gray` or `aqua` and `cyan`.
+A few colors have multiple names referring to the same colors, e.g. `grey` and `gray` or `aqua` and `cyan`.
 
-In these cases the _last_ color when sorted alphabetically takes preferences,
+In these cases the _last_ color when sorted alphabetically takes precedence.
 eg. `Color((0, 255, 255)).as_named() == 'cyan'` because "cyan" comes after "aqua".
 """
 
@@ -12,16 +12,16 @@ from __future__ import annotations
 import math
 import re
 from colorsys import hls_to_rgb, rgb_to_hls
-from typing import Any, Callable, Literal, Union, cast
+from typing import Any, Callable, Literal, Tuple, Union, cast
 
 from pydantic import GetJsonSchemaHandler
 from pydantic._internal import _repr
 from pydantic.json_schema import JsonSchemaValue
 from pydantic_core import CoreSchema, PydanticCustomError, core_schema
 
-ColorTuple = Union[tuple[int, int, int], tuple[int, int, int, float]]
+ColorTuple = Union[Tuple[int, int, int], Tuple[int, int, int, float]]
 ColorType = Union[ColorTuple, str, 'Color']
-HslColorTuple = Union[tuple[float, float, float], tuple[float, float, float, float]]
+HslColorTuple = Union[Tuple[float, float, float], Tuple[float, float, float, float]]
 
 
 class RGBA:
@@ -115,7 +115,7 @@ class Color(_repr.Representation):
         """
         if self._rgba.alpha is not None:
             return self.as_hex()
-        rgb = cast(tuple[int, int, int], self.as_rgb_tuple())
+        rgb = cast('tuple[int, int, int]', self.as_rgb_tuple())
 
         if rgb in COLORS_BY_VALUE:
             return COLORS_BY_VALUE[rgb]
@@ -354,7 +354,7 @@ def parse_color_value(value: int | str, max_val: int = 255) -> float:
     """
     try:
         color = float(value)
-    except ValueError as e:
+    except (ValueError, TypeError) as e:
         raise PydanticCustomError(
             'color_error',
             'value is not a valid color: color values must be a valid number',
